@@ -315,6 +315,13 @@ impl EspWifi {
         f(self.sta_netif.as_ref())
     }
 
+    pub fn with_client_netif_mut<F, T>(&mut self, f: F) -> T
+    where
+        F: FnOnce(Option<&mut EspNetif>) -> T,
+    {
+        f(self.sta_netif.as_mut())
+    }
+
     pub fn with_router_netif<F, T>(&self, f: F) -> T
     where
         F: FnOnce(Option<&EspNetif>) -> T,
@@ -322,6 +329,13 @@ impl EspWifi {
         f(self.ap_netif.as_ref())
     }
 
+    pub fn with_router_netif_mut<F, T>(&mut self, f: F) -> T
+    where
+        F: FnOnce(Option<&mut EspNetif>) -> T,
+    {
+        f(self.ap_netif.as_mut())
+    }
+
     fn get_client_conf(&self) -> Result<ClientConfiguration, EspError> {
         let mut wifi_config = [0 as u8; mem::size_of::<wifi_config_t>()];
         let wifi_config_ref: &mut wifi_config_t = unsafe { mem::transmute(&mut wifi_config) };
